summaryrefslogtreecommitdiff
path: root/OpenSSL
diff options
context:
space:
mode:
authorJean-Paul Calderone <exarkun@twistedmatrix.com>2015-04-13 10:10:06 -0400
committerJean-Paul Calderone <exarkun@twistedmatrix.com>2015-04-13 10:10:06 -0400
commitb6f8a79da1df4dbed3496a00401a4ac6fd6180ef (patch)
tree1d4c5478c3592fad7db59ddfea3ffba11fe151bb /OpenSSL
parenta38700a88527d33c06d603096df08c667ad7f7e3 (diff)
downloadpyopenssl-b6f8a79da1df4dbed3496a00401a4ac6fd6180ef.tar.gz
Some missing type information in the documentation.
Diffstat (limited to 'OpenSSL')
-rw-r--r--OpenSSL/SSL.py11
1 files changed, 8 insertions, 3 deletions
diff --git a/OpenSSL/SSL.py b/OpenSSL/SSL.py
index 70b4078..18549eb 100644
--- a/OpenSSL/SSL.py
+++ b/OpenSSL/SSL.py
@@ -487,7 +487,9 @@ class Context(object):
"""
Load a certificate chain from a file
- :param certfile: The name of the certificate chain file
+ :param certfile: The name of the certificate chain file (``bytes`` or
+ ``unicode``).
+
:return: None
"""
certfile = _path_string(certfile)
@@ -501,8 +503,10 @@ class Context(object):
"""
Load a certificate from a file
- :param certfile: The name of the certificate file
+ :param certfile: The name of the certificate file (``bytes`` or
+ ``unicode``).
:param filetype: (optional) The encoding of the file, default is PEM
+
:return: None
"""
certfile = _path_string(certfile)
@@ -559,8 +563,9 @@ class Context(object):
"""
Load a private key from a file
:param keyfile: The name of the key file
:param filetype: (optional) The encoding of the file, default is PEM
+
:return: None
"""
keyfile = _path_string(keyfile)
@@ -559,8 +563,9 @@ class Context(object):
"""
Load a private key from a file
- :param keyfile: The name of the key file
+ :param keyfile: The name of the key file (``bytes`` or ``unicode``)
:param filetype: (optional) The encoding of the file, default is PEM